California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| CAMPAIGN FINANCE: Candidates & Elected Officials
Choose a Listing: Certified Election Candidates Incumbent Elected State Officials Candidates and Elected Officials By Name Who filed a Statement of Intention to run for What State Office? (Filers may not have qualified for the ballot) CalPERS and CalSTRS Candidate Filings, Scanned Images |
Go to Section:
| Statewide Candidates
| State Senate Candidates
| State Assembly Candidates
Choose an Election: 2022 PRIMARY 2021 SPECIAL ELECTION (ASSEMBLY 54) Prior Elections 2021 SPECIAL ELECTION (ASSEMBLY 79) 2021 SPECIAL ELECTION (STATE SENATE 30) 2020 GENERAL 2020 SPECIAL RUNOFF (STATE SENATE 28) 2020 PRIMARY 2020 SPECIAL ELECTION (STATE SENATE 28) 2019 SPECIAL RUNOFF (ASSEMBLY 01) 2019 SPECIAL ELECTION (ASSEMBLY 01) 2019 SPECIAL RUNOFF (STATE SENATE 01) 2019 SPECIAL RUNOFF (STATE SENATE 33) 2019 SPECIAL ELECTION (STATE SENATE 01) 2019 SPECIAL ELECTION (STATE SENATE 33) 2018 GENERAL 2018 SPECIAL RUNOFF (STATE SENATE 32) 2018 PRIMARY 2018 SPECIAL ELECTION (STATE SENATE 32) 2018 SPECIAL ELECTION (STATE SENATE 29) 2018 SPECIAL RUNOFF (ASSEMBLY 45) 2018 SPECIAL RUNOFF (ASSEMBLY 39) 2018 SPECIAL ELECTION (ASSEMBLY 45) 2018 SPECIAL ELECTION (ASSEMBLY 54) 2018 SPECIAL ELECTION (ASSEMBLY 39) 2017 SPECIAL RUNOFF (ASSEMBLY 51) 2017 SPECIAL ELECTION (ASSEMBLY 51) 2016 GENERAL 2016 PRIMARY 2016 SPECIAL ELECTION (ASSEMBLY 31) 2015 SPECIAL RUNOFF (STATE SENATE 07) 2015 SPECIAL ELECTION (STATE SENATE 37) 2015 SPECIAL ELECTION (STATE SENATE 21) 2015 SPECIAL ELECTION (STATE SENATE 07) 2014 SPECIAL ELECTION (STATE SENATE 35) 2014 GENERAL 2014 PRIMARY 2014 SPECIAL ELECTION (STATE SENATE 23) 2013 SPECIAL ELECTION (ASSEMBLY 54) 2013 SPECIAL RUNOFF (ASSEMBLY 45) 2013 SPECIAL RUNOFF (ASSEMBLY 52) 2013 SPECIAL ELECTION (STATE SENATE 26) 2013 SPECIAL ELECTION (ASSEMBLY 45) 2013 SPECIAL ELECTION (ASSEMBLY 52) 2013 SPECIAL RUNOFF (STATE SENATE 16) 2013 SPECIAL ELECTION (ASSEMBLY 80) 2013 SPECIAL ELECTION (STATE SENATE 16) 2013 SPECIAL RUNOFF (STATE SENATE 32) 2013 SPECIAL ELECTION (STATE SENATE 40) 2013 SPECIAL ELECTION (STATE SENATE 32) 2013 SPECIAL ELECTION (STATE SENATE 04) 2012 GENERAL 2012 SPECIAL ELECTION (STATE SENATE 04) 2012 PRIMARY 2011 SPECIAL RUNOFF (ASSEMBLY 04) 2011 SPECIAL ELECTION (ASSEMBLY 04) 2011 SPECIAL ELECTION (STATE SENATE 17) 2011 SPECIAL ELECTION (STATE SENATE 28) 2011 SPECIAL RUNOFF (STATE SENATE 01) 2010 GENERAL 2010 SPECIAL ELECTION (STATE SENATE 01) 2010 SPECIAL RUNOFF (STATE SENATE 15) 2010 SPECIAL ELECTION (STATE SENATE 15) 2010 PRIMARY 2010 SPECIAL RUNOFF (STATE SENATE 37) 2010 SPECIAL RUNOFF (ASSEMBLY 43) 2010 SPECIAL ELECTION (STATE SENATE 37) 2010 SPECIAL ELECTION (ASSEMBLY 43) 2010 SPECIAL RUNOFF (ASSEMBLY 72) 2009 SPECIAL ELECTION (ASSEMBLY 72) 2009 SPECIAL ELECTION (ASSEMBLY 51) 2009 SPECIAL RUNOFF (STATE SENATE 26) 2009 SPECIAL ELECTION (STATE SENATE 26) 2008 GENERAL 2008 PRIMARY 2008 RECALL (STATE SENATE 12) 2008 SPECIAL RUNOFF (ASSEMBLY 55) 2007 SPECIAL ELECTION (ASSEMBLY 55) 2007 SPECIAL ELECTION (ASSEMBLY 39) 2006 GENERAL 2006 PRIMARY 2006 SPECIAL RUNOFF (STATE SENATE 35) 2006 SPECIAL ELECTION (STATE SENATE 35) 2005 SPECIAL ELECTION (ASSEMBLY 53) 2004 GENERAL 2004 PRIMARY 2003 SPECIAL ELECTION (GOVERNOR) 2002 GENERAL 2002 PRIMARY 2001 SPECIAL ELECTION (ASSEMBLY 49) 2001 SPECIAL RUNOFF (ASSEMBLY 65) 2001 SPECIAL ELECTION (STATE SENATE 24) 2001 SPECIAL ELECTION (ASSEMBLY 65) 2000 GENERAL 2000 PRIMARY
Also check Late Contribution filings. These reports are independent of the comprehensive disclosure reports that are linked here until semi-annual filings are submitted.
STATEWIDE OFFICES
GOVERNOR
ANGELIDES, PHIL BECNEL, BARBARA BROUILLETE, JOE BURNS, JEFFREY R. CAMEJO, PETER MIGUEL CHAMBERS, WILLIAM S. GERST, JERALD R. GREENE, VIBERT F. JORDAN, JANICE MACALUSO, FRANK A. NEWMAN II, ROBERT C. NOONAN, EDWARD C. OLIVIER, ARTHUR C. SCHWARZENEGGER, ARNOLD STRIMLING, MICHAEL WESTLY, STEVE
| LIEUTENANT GOVERNOR
ALEXANDER, STEWART A. FARMER, ANTHONY N. FIGUEROA, LIZ GARAMENDI, JOHN MC CLINTOCK, THOMAS SHAW, LYNNETTE M. SPEIER, JACQUELINE WARREN, DONNA J.
SECRETARY OF STATE
AKIN, MARGIE BOWEN, DEBRA HILL, FORREST LIGHTFOOT, GAIL K. MC MILLON, GLENN L. MC PHERSON, BRUCE ORTIZ, DEBORAH V.
| CONTROLLER
BARRON, ELIZABETH C. CAMPBELL, WARREN MARK CHIANG, JOHN DAVIS, BRET R. DUNN, JOSEPH HARRIS, DAVID MALDONADO, ABEL STIERINGER, JAMES G. STRICKLAND, TONY TELLO, DONNA WELLS, LAURA
TREASURER
LOCKYER, BILL NOONAN, JUSTIN E. PARRISH, CLAUDE RICHMAN, KEITH STUART SANDERS, GERALD SMITHSON, MARIAN V. THAKKER, MEHUL
| ATTORNEY GENERAL
BROWN, EDMUND G. (JERRY) DELGADILLO, ROCKARD J. HARRISON, JACK L. POOCHIGIAN, CHUCK WEISSMAN, KENNETH A. WYMAN, MICHAEL S.
SUPERINTENDENT OF PUBLIC INSTRUCTION
BUNTING, DANIEL L. KNOPP, SARAH L. LENNING, DIANE A. MC MICKEN, GRANT M. O'CONNELL, JACK
| INSURANCE COMMISSIONER
BURDEN, JAY EARL BUSTAMANTE, CRUZ M. CAFIERO, LAWRENCE CONDIT, TOM KRAFT, JOHN OGDEN, DALE F. POIZNER, STEVE
BOARD OF EQUALIZATION
MEMBER BOARD OF EQUALIZATION 01
CAMPBELL, DAVID NEIGHBORS, DAVID J. WATSON, KENNITA L. YEE, BETTY T.
| MEMBER BOARD OF EQUALIZATION 02
BRIGHT, TOM LEONARD, BILL MICHLIN, WILLARD D. PERRY, RICHARD R. RABOY, TIM STREICHMAN, EDWARD C.
MEMBER BOARD OF EQUALIZATION 03
CHRISTIAN-HEISING, MARY DA SILVA, LEWIS A. FINLEY, MARY LOU HAYNES, RAYMOND N. PETRUZZO, STEPHEN M. STEEL, MICHELLE STYLES, HAL JIMBO
| MEMBER BOARD OF EQUALIZATION 04
ABBOTT, VONNY T. CHU, JUDY FORSCH, GLEN R. HENDERSON, CINDY VARELA HORTON, JEROME E. KADERA, MONICA W. PARK, SAMUEL ROGERS, RITA WONG, JOHN Y.
SENATE DISTRICTS
STATE SENATE 02
WIESNER, LAWRENCE R. WIGGINS, PATRICIA ANN
| STATE SENATE 04
AANESTAD, SAMUEL M. MUNROE, TONY SINGH, PAUL R. VIZZARD, ROBERT WELLS
STATE SENATE 06
GARBEROGLIO, ALANA N. GREEN JR., PAUL ROBINSON HAWKINS, SAMUEL J. STEINBERG, DARRELL WEBER, C.T.
| STATE SENATE 08
BRAUN, OSCAR ALEJANDRO NEVIN, MICHAEL D. PAPAN, LOU SKIPAKEVICH, MICHAEL YEE, LELAND Y.
STATE SENATE 10
CORBETT, ELLEN DUTRA, JOHN A. FILIPOVICH, LOU KLEHS, JOHAN RIFFLE, LAURA A.
| STATE SENATE 12
DENHAM, JEFF NICKEL III, GEORGE W.
STATE SENATE 14
COGDILL, DAVID E. FIRCH, WESLEY W.
| STATE SENATE 16
FLOREZ, DEAN
STATE SENATE 18
ASHBURN, ROY DAVIS, FRED B. RICK, MATTHEW
| STATE SENATE 20
BROWN, PAMELA J. MONTANEZ, CINDY PADILLA, ALEX
STATE SENATE 22
CEDILLO, GILBERT LEVY, MURRAY TEN, MIKE
| STATE SENATE 24
CARVER, ROBERT W.
STATE SENATE 26
MC COY, MARVIN C. RAYMOND, BUD F. RIDLEY-THOMAS, MARK
| STATE SENATE 28
ANSTROM, DAVID LEE DE BAETS, PETER D. LIDDLE, CHERRYL NAKANO, GEORGE OROPEZA, JENNY
STATE SENATE 30
BERMUDEZ, RUDY CALDERON, RONALD MINERD, SELMA
| STATE SENATE 32
BACA JR., JOE MC LEOD, GLORIA NEGRETE
STATE SENATE 34
CORREA, LOU DAUCHER, LYNN MORENO, LUPE O. UMBERG, THOMAS J.
| STATE SENATE 36
HANSON, MARK N. HOLLINGSWORTH, DENNIS QUINTANA, REBEKAH SHEA, JOE B.
STATE SENATE 38
KLEA, BRIAN A. WYLAND, MARK B.
| STATE SENATE 40
DUCHENY, DENISE MORENO THOMAS, JESSE WALDEN, DAVID K.
ASSEMBLY DISTRICTS
ASSEMBLY 01
BERG, PATTY REED, THOMAS T. TYRONE, RAY
| ASSEMBLY 02
DYNAN, PHILIP E. HENNEMANN, RAYMOND G. LA MALFA, DOUG SMITH, MEL
ASSEMBLY 03
HARRINGTON, MICHAEL "MICKEY" KEENE, RICHARD J.
| ASSEMBLY 04
FRITTS, GERALD M. GAINES, EDWARD T HASWELL, ROB HUNT, RONALD PAUL MURPHY, MICHAEL PATRICK
ASSEMBLY 05
BELL, BRANDON R. LOPEZ, MICHAEL NIELLO, ROGER
| ASSEMBLY 06
ALDEN, JOHN W. CONNOLLY, DAMON M. EASTON-BROWN, ALEX HARTNETT, MICHAEL HUFFMAN, JARED MURRAY, CYNTHIA L. OLMSTEAD, RICHARD TORLIATT, PAMELA WOODS, CAT
ASSEMBLY 07
EVANS, NOREEN M.
| ASSEMBLY 08
GOULD, JOHN S. WOLK, LOIS
ASSEMBLY 09
CHAN, WILLIAM JONES, DAVE
| ASSEMBLY 10
BONSER, JANICE M. COOK, COLONEL JIM A. NAKANISHI, ALAN S. TATE, KEVIN E.
ASSEMBLY 11
CANCIAMILLA, LAURA S. DE SAULNIER, MARK GORMAN, GEROLD L. NOTT, CORY M. OGUNLEYE, EMMANUEL OLUGBENGA SIMONSEN, ARNE
| ASSEMBLY 12
EPSTEIN, HOWARD HERMANSON, BARRY MA, FIONA REILLY, JANET
ASSEMBLY 13
LENO, MARK MALDONADO JR., RAMIRO NEIRA, GAIL E.
| ASSEMBLY 14
HANCOCK, LONI WOLF, LEIGH N.
ASSEMBLY 15
COLEMAN, TERRY HOUSTON, GUY
| ASSEMBLY 16
CAPLANE, RONNIE GAIL DAYSOG, ANTHONY H. RUSSO, JOHN A. SWANSON, SANDRE YTUARTE, EDWARD
ASSEMBLY 17
GALGIANI, CATHLEEN MACHADO, GERARD J. SWEET, WILLIAM RALPH JR. TUCKER, SUZANNE
| ASSEMBLY 18
BUCK, JILL ANN HAYASHI, MARY MC CAMMON, WILLIAM J.
ASSEMBLY 19
COEN, COLLEEN GUFLER, ELSIE MULLIN, GENE R.
| ASSEMBLY 20
NISHIMURA, KEN A. TORRICO, ALBERTO
ASSEMBLY 21
KIRALY, VIRGINIA C. RUSKIN, IRA
| ASSEMBLY 22
LIEBER, SALLY RIFFENBURGH, ROGER RALPH
ASSEMBLY 23
COTO, JOE PATROSSO, MARK
| ASSEMBLY 24
BEALL, JIM HILEMAN, LAWRENCE R. SILVA, LIONEL H.
ASSEMBLY 25
BERRYHILL, TOM BUFFORD, JAMES LEX CONRAD, BILL DELL'ORTO, MICHAEL RAY
| ASSEMBLY 26
AGHAZARIAN, GREG GOEKEN, KENNETH J.
ASSEMBLY 27
LAIRD, JOHN S. MORRISON, COLIN M.
| ASSEMBLY 28
CABALLERO, ANNA PHARES, ANN VENTURA VELAZQUEZ, IGNACIO
ASSEMBLY 29
AVILA, BENJAMIN CROCKFORD, JOHN VILLINES, MICHAEL N. ZWICKEL, JONATHAN IRA
| ASSEMBLY 30
CRAWFORD SR., WESLEY GILMORE, DANNY D. PARRA, NICOLE
ASSEMBLY 31
ARAMBULA, JUAN
| ASSEMBLY 32
ELLIS, STANLEY WILLIAM FULLER, JEAN VEGA, MARIBEL WYMAN, PHILLIP D.
ASSEMBLY 33
BLAKESLEE, SAM CUTHBERT, ROBERT
| ASSEMBLY 34
MAZE, BILL SILVA, DAVID MINTON ZELLHOEFER, JON W.
ASSEMBLY 35
MARTIN, CRISTINA CARRENO NAVA, PEDRO I.
| ASSEMBLY 36
BYNUM, ROBERT "BO" LEDFORD, JAMES C. RUNNER, SHARON
ASSEMBLY 37
LARKIN, BOB MASRY, FERIAL STRICKLAND, AUDRA
| ASSEMBLY 38
ALGER, JIM BARRIENTOS, MARY CHRISTENSEN, PEGGY L. GOLD, SID LOWENTHAL, JANE F. SHAW, LYN SMYTH, CAMERON
ASSEMBLY 39
ALARCON, RICHARD
| ASSEMBLY 40
CHELEBIAN, ARMINEH LEVINE, LLOYD MONTAINE, RICHARD E.
ASSEMBLY 41
BROWNLEY, JULIA DOLZ, TONY FRANKOWSKI, CONRAD S. GROVEMAN, BARRY HAYES-RAITT, KELLY LEVEY, JONATHAN O'BRIEN, SHAWN CASEY VAN HEMERT, ADRIANA
| ASSEMBLY 42
BAKER, CLARK W. FEUER, MICHAEL NELSON FINE, ERIC MICHAEL GOLDMAN, COLIN S. GONZAGA, MARK LAND, ABBE SION, STEVEN MARK TOUSSAINT, CYNTHIA L.
ASSEMBLY 43
AGBABA, MICHAEL M. KREKORIAN, PAUL MYERS, STEVEN A. QUINTERO, FRANK
| ASSEMBLY 44
CARWILE, SCOTT CENTER, BRIAN COSTA, RICARDO M. KOEBEL, PHILIP MURRAY, ADAM PETERSON-MORE, DIANA L. PORTANTINO, ANTHONY YANAGA, BARRON T.
ASSEMBLY 45
ALLEN-NEWMAN, SAMANTHA BUELNA, GABRIEL CHAVEZ, CHRISTINA DE LEON, KEVIN GUTIERREZ, OSCAR A. POPP, ELENA I.
| ASSEMBLY 46
NUNEZ, FABIAN
ASSEMBLY 47
BASS, KAREN DODGE, JEFFERS MAC ARTHUR
| ASSEMBLY 48
DAVIS, MIKE GREEN, BRENDA CAROL TURNER, EDWARD R. WILLOUGHBY, ANTHONY
ASSEMBLY 49
ARGUELLO, DANIEL BROWN, LAURA G. ENG, MICHAEL SIEGRIST, DAVID S. SIEGRIST, ESTHELA G.
| ASSEMBLY 50
DE LA TORRE, HECTOR MILLER, GLADYS O.
ASSEMBLY 51
BRADFORD, STEVEN MOEN, ROSS PRICE, CURREN D.
| ASSEMBLY 52
DYMALLY, MERVYN M.
ASSEMBLY 53
ABRAMS, KARL FORD, MARY JO LIEU, TED THOTTAM, PETER L.
| ASSEMBLY 54
GLAVICH, DONALD H. JACKSON, MICHAEL A. KARNETTE, BETTY
ASSEMBLY 55
FURUTANI, WARREN RICHARDSON, LAURA UNDERHILL, MARGHERITA
| ASSEMBLY 56
FLOWERS-ZUNIGA, SALLY A. HU, GRACE MENDOZA, TONY RAMIREZ, RICK
ASSEMBLY 57
CARVER, HOLLY E. CHAVEZ, RENEE HERNANDEZ, EDWARD P. MC FADDEN, BRADLEY J. SOLIS, JOHN M.
| ASSEMBLY 58
ARMENTA, DAVID W. CALDERON, CHARLES M. GUZMAN, GERRI KLEINPELL, JIM NEWCOMER, OWEN
ASSEMBLY 59
ADAMS, ANTHONY BARKAN, ELLIOTT ROBERT HARTZ, BARRY K. LANCASTER, CHRISTOPHER W. OTTO, KEVAN SLATER, SUSAN STONE, JILL K.
| ASSEMBLY 60
HUFF, ROBERT 'BOB' TAMOM, VANNARITH THOMAS
ASSEMBLY 61
AVILA, PAUL VINCENT LOPEZ, BENJAMIN I. SOTO, NELL
| ASSEMBLY 62
BACA, JEREMY CARTER, WILMER AMINA MENDOZA-WARE, MARGE
ASSEMBLY 63
EMMERSON, BILL WESTWOOD, MARK DAVID
| ASSEMBLY 64
BENOIT, JOHN J. RASSO, PAUL M.
ASSEMBLY 65
AYRES, JIM COOK, PAUL J. LOWE, ROBIN R. RAMIREZ-DEAN, RITA SALAS, BRENDA SMITH, KEN D. TALEB, JON
| ASSEMBLY 66
ADAMS, STEVE BRANSTINE, DAN JEFFRIES, KEVIN D. KNIGHT, NANCY L. NICHOLSON, LAUREL A.
ASSEMBLY 67
HARMAN, DIANNE D. MC GILL, MICHAEL JOSEPH ROBERTS, RAYMOND L. SILVA, JAMES W.
| ASSEMBLY 68
LUCAS, PAUL PHAM, LONG K. TRAN, VAN
ASSEMBLY 69
ALVAREZ, CLAUDIA DE LA LIBERTAD, ARMANDO SOLORIO, JOSE WILLIAMS, RYAN GENE
| ASSEMBLY 70
DE VORE, CHARLES S.
ASSEMBLY 71
LA CHANCE, IRENE SPITZER, TODD
| ASSEMBLY 72
CROSS, BRIAN LEE DUVALL, MIKE MAC MURRAY, JOHN P. SIMONOFF, MARTY
ASSEMBLY 73
FAVOR, ANDREW H.
| ASSEMBLY 74
FOLESCU, ROXANA GARRICK, MARTIN W. PACKARD, SCOTT D. WALDRON, MARIE
ASSEMBLY 75
MEYER, SCOTT PLESCIA, GEORGE A. TEYSSIER, EDWARD M.
| ASSEMBLY 76
DENNEY, RALPH PERWIN, JEFFREY H. SALDANA, LORI
ASSEMBLY 77
ANDERSON, JOEL C. BEECHAM, NANCY LEE BELITZ, RICHARD G. BEYER, DEBBIE M. DALE, JACK JENKIN, WILLIAM R. LARKIN, CHRISTOPHER
| ASSEMBLY 78
GASTIL, GEORGE C. GIBSON, GEOF C. HORTON, SHIRLEY SHERARD, MAXINE J.
ASSEMBLY 79
ALBRITTEN, JESSE ROESCH, JEAN DR. SALAS, MARY H. SANDOVAL, GREG
| ASSEMBLY 80
CLUTE, STEVE W. GARCIA, BONNIE ODEN, RON